from setuptools import setup, find_packages

setup(
    name="upset-altair",
    version="0.1.0",
    description="Altair-based interactive UpSet plots",
    url="https://github.com/hms-dbmi/upset-altair",
    author="Sehi L'Yi",
    author_email="sehi_lyi@hms.harvard.edu",
    license="MIT",
    packages=find_packages()
)